[![Build Status](https://travis-ci.org/xchem/fragalysis.svg?branch=master)](https://travis-ci.org/xchem/fragalysis)
[![stable](http://badges.github.io/stability-badges/dist/stable.svg)](http://github.com/badges/stability-badges)
[![Version](http://img.shields.io/badge/version-0.0.40-blue.svg?style=flat)](https://github.com/xchem/fragalysis)
[![License](http://img.shields.io/badge/license-Apache%202.0-blue.svg?style=flat)](https://github.com/xchem/fragalysis/blob/master/LICENSE.txt)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/xchem/fragalysis.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/xchem/fragalysis/context:python)

Basic RDKit based Python tools for analysis of protein-ligand interactions.

Currently contains two things.

1. Clustering - based on WONKA method - but sepearated from that code-base. Cluster waters, residues, ligands and pharmacophores. (Under development).

2. Astex Fragment Network - implementation on the basis of their recent paper

3. Conformer generation code - based on known X-ray structures
